<?php
/**
* @author     stepFORM <team@stepform.io>
* @date       30/08/2019
* @copyright  Copyright (C) 2019 stepFORM. All rights reserved.
* @license    GNU General Public License version 2 or later; see LICENSE
*/
defined('_JEXEC') or die;

class stepFORMAjax extends stepFORMCore
{

  /**
  * Ajax request response
  */
  private $response;

  /**
  * Ajax request format
  */
  private $format;

  /**
  * Ajax request language
  */
  protected $lang;


  /**
  * Constructor
  */
  public function __construct()
  {
    parent::__construct();

    if ($this->app->input->getCmd('format') === 'json') {
      $this->app->setHeader('Content-Type', 'application/json', true)->sendHeaders();
    } elseif ($this->app->input->getCmd('format') === 'html') {
      $this->app->setHeader('Content-Type', 'text/html', true)->sendHeaders();
    } else {
      echo 'This format does not exist.';
      exit();
    }

    $status = $this->checkPluginStatus();

    if ($status !== true) {
      $this->response = $status;
      return;
    }

    $this->format = $this->app->input->getCmd('format');
    $method = strtolower($this->app->input->getMethod());
    $cmd_method = strtolower($this->app->input->getCmd('method'));

    if (method_exists($this, $method . $cmd_method)) {
      $this->response = call_user_func_array(array(
        $this, $method . $cmd_method
      ), array());
    } else {
      $this->response = array(
        'status' => false,
        'message' => 'This method is not allowed.'
      );
    }
  }

  /**
  * Get a list of user forms
  *
  * @return mixed User form list
  */
  public function getAllForms()
  {
    if ($this->format == 'json') {
      return array(
        'status' => true,
        'data' => $this->UserAllForms()
      );
    }

    if ($this->format == 'html') {
      $forms = $this->UserAllForms();

      if (empty(($forms))) {
        return JText::_('PLG_STEPFORM_FORMS_EMPTY');
      }

      $res = '<p style="font-family:Helvetica,Arial,sans-serif;padding-top:12px;">'.$this->lang->_('PLG_STEPFORM_POPUP_SELECT_STRING').'</p>';
      $res .= '<select style="width: 100%">';

      foreach ($forms as $item) {
        $res .= '<option ' .
        'value="' . $item['virtual_id'] . '" ' .
        'data-forms_screen="' . $item['form_screen'] . '">' .
        $item['form_name'] . '</option>';
      }
      $res .= '</select>';
      $res .= '<script>parent.stepFORM_modal()</script>';

      return $res;
    }

    return '';
  }

  /**
  * Get response
  * @return mixed response
  */
  public function response()
  {
    return $this->response;
  }

}
