<?php
/**
* @author     stepFORM <team@stepform.io>
* @date       30/08/2019
* @copyright  Copyright (C) 2019 stepFORM. All rights reserved.
* @license    GNU General Public License version 2 or later; see LICENSE
*/
defined('_JEXEC') or die;

if (!defined('stepFORM_PluginName')) {
  define('stepFORM_PluginName', 'stepFORM');
}

if (!defined('stepFORM_PluginType')) {
  define('stepFORM_PluginType', 'content');
}

if (!defined('stepFORM_PluginDir')) {
  define('stepFORM_PluginDir', dirname(__FILE__));
}

require_once dirname(__FILE__) . '/classes/core.php';
require_once dirname(__FILE__) . '/classes/ajax.php';


/**
* Class plgContentstepFORM
*/
class plgContentstepFORM extends JPlugin
{

  /**
  * Constructor
  *
  * @param [type] $subject Object data
  * @param array  $config  Array of configurations
  */
  public function __construct($subject, array $config = array())
  {
    parent::__construct($subject, $config);
    $language = JFactory::getLanguage();
    $language->load('plg_content_stepFORM.sys', stepFORM_PluginDir, null, true);
  }

  /**
  * [onContentBeforeDisplay description]
  * @param  string  $context The context of the content being passed to the plugin - this is the component name and view - or name of module
  * @param  array  $row     The article that is being rendered by the view.
  * @param  array  $params  An associative array of relevant parameters.
  * @param  integer $page     An integer that determines the "page" of the content that is to be generated.
  */
  public function onContentBeforeDisplay($context, &$row, &$params, $page = 0)
  {

  }

  /**
  * This is an event that is called when a module on the front- or back-end is rendered.
  *
  * @param refs $module  A reference to a Module object that holds all the data of the module
  * @param refs $attribs An array of attributes for the module
  * @return [type]          [description]
  */
  public function onRenderModule(&$module, &$attribs)
  {
    if (isset($module->content)) {
      $module->content = $this->ReplaceFormShortCode($module->content);
    }
  }


  /**
  * Prepare for content
  *
  * @param  object  $context The context of the content passed to the plugin.
  * @param  object  $row     A reference to the article that is being rendered by the view.
  * @param  array  $params  A reference to an associative array of relevant parameters.
  * @param  integer $page   An integer that determines the "page" of the content that is to be generated.
  * @return [type]           [description]
  */
  public function onContentPrepare($context, &$row, &$params, $page = 0)
  {
    if (isset($row->text)) {
      $row->text = $this->ReplaceFormShortCode($row->text);
    }

    if (isset($row->introtext)) {
      $row->introtext = $this->ReplaceFormShortCode($row->introtext);
    }
  }


/**
 * Replace short form code
 *
 * @param string $text shortcode text
 */
  private function ReplaceFormShortCode($text)
  {
    $pattern = '~\[stepFORM id=([0-9a-zA-Z]+?)\]~u';
    preg_match_all($pattern, $text, $preg);

    if (!empty($preg['1'])) {
      foreach ($preg['1'] as $key => $row) {
        $round = rand (1000000, 9999999);

        $code = '<div class="stepform_' . $row . ' rnd_' . $round . '"></div><script>(function(s, t, e, p, f, o, r, m) { s[t] = s[t] || {}; s[t][' . $round . '] = { id: "' . $row . '", rnd: ' . $round . '}; e.async = true; e.src = p + f; document[m](o)[r](e) } (window,"stepFORM_params",document.createElement("script"),document.location.protocol==="https:"?"https:":"http:","//app.stepform.io/api.js?id=' . $row . '","head","appendChild","querySelector"));</script>';

        $text = str_replace($preg['0'][$key], $code, $text);
      }
    }
    return $text;
  }


  /**
  * Getting ajax data
  * @return object ajax response
  */
  public function onAjaxstepFORM()
  {
    echo (new stepFORMAjax())->response();
    exit();
  }

}

/**
* New core object
* @var [type]
*/
if (class_exists('stepFORMCore')) {
  new stepFORMCore();
}
